[patch 33/43] rename add_ktimeout_on() to ktimeout_add_on()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



plain text document attachment (ktimeout-rename-ktimeout_add_on.patch)
- rename add_ktimeout_on() to ktimeout_add_on()

Signed-off-by: Ingo Molnar <[email protected]>

 include/linux/ktimeout.h |    2 +-
 include/linux/timer.h    |    2 +-
 kernel/ktimeout.c        |    6 +++---
 3 files changed, 5 insertions(+), 5 deletions(-)

Index: linux/include/linux/ktimeout.h
===================================================================
--- linux.orig/include/linux/ktimeout.h
+++ linux/include/linux/ktimeout.h
@@ -60,7 +60,7 @@ static inline int ktimeout_pending(const
 	return ktimeout->entry.next != NULL;
 }
 
-extern void add_ktimeout_on(struct ktimeout *ktimeout, int cpu);
+extern void ktimeout_add_on(struct ktimeout *ktimeout, int cpu);
 extern int del_ktimeout(struct ktimeout * ktimeout);
 extern int __mod_ktimeout(struct ktimeout *ktimeout, unsigned long expires);
 extern int mod_ktimeout(struct ktimeout *ktimeout, unsigned long expires);
Index: linux/include/linux/timer.h
===================================================================
--- linux.orig/include/linux/timer.h
+++ linux/include/linux/timer.h
@@ -19,7 +19,7 @@
 #define init_timer			ktimeout_init
 #define setup_timer			ktimeout_setup
 #define timer_pending			ktimeout_pending
-#define add_timer_on			add_ktimeout_on
+#define add_timer_on			ktimeout_add_on
 #define del_timer			del_ktimeout
 #define __mod_timer			__mod_ktimeout
 #define mod_timer			mod_ktimeout
Index: linux/kernel/ktimeout.c
===================================================================
--- linux.orig/kernel/ktimeout.c
+++ linux/kernel/ktimeout.c
@@ -237,13 +237,13 @@ int __mod_ktimeout(struct ktimeout *ktim
 EXPORT_SYMBOL(__mod_ktimeout);
 
 /***
  * add_ktimeout_on - start a timeout on a particular CPU
  * @ktimeout: the timeout to be added
  * @cpu: the CPU to start it on
  *
  * This is not very scalable on SMP. Double adds are not possible.
  */
-void add_ktimeout_on(struct ktimeout *ktimeout, int cpu)
+void ktimeout_add_on(struct ktimeout *ktimeout, int cpu)
 {
 	tvec_base_t *base = &per_cpu(tvec_bases, cpu);
   	unsigned long flags;
@@ -364,7 +364,7 @@ out:
  * otherwise this function is meaningless. It must not be called from
  * interrupt contexts. The caller must not hold locks which would prevent
  * completion of the timeout's handler. The timeout's handler must not call
  * add_ktimeout_on(). Upon exit the timeout is not queued and the handler is
  * not running on any CPU.
  *
  * The function returns whether it has deactivated a pending timeout or not.
@@ -237,13 +237,13 @@ int __mod_ktimeout(struct ktimeout *ktim
 
 /***
- * add_ktimeout_on - start a timeout on a particular CPU
+ * ktimeout_add_on - start a timeout on a particular CPU
  * @ktimeout: the timeout to be added
  * @cpu: the CPU to start it on
@@ -364,7 +364,7 @@ out:
  * interrupt contexts. The caller must not hold locks which would prevent
  * completion of the timeout's handler. The timeout's handler must not call
- * add_ktimeout_on(). Upon exit the timeout is not queued and the handler is
+ * ktimeout_add_on(). Upon exit the timeout is not queued and the handler is
  * not running on any CPU.
  *

--

-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

[Index of Archives]     [Kernel Newbies]     [Netfilter]     [Bugtraq]     [Photo]     [Stuff]     [Gimp]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Video 4 Linux]     [Linux for the blind]     [Linux Resources]
  Powered by Linux